@@ -6,11 +6,13 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+from .inventorylevel import InventoryLevel
 from .order import Order
 from .product import Product
 
 
 __all__: list[str] = [
+    'InventoryLevel',
     'Order',
     'Product',
 ]
\ No newline at end of file
